import {
  Component,
  Input,
  OnInit,
  EventEmitter,
  Output,
  ViewChild,
  OnDestroy,
  ElementRef
} from '@angular/core';
import { Node } from '../../model/node';
import { Link } from '../../model/link';
import { Zone } from '@overflow/model/discovery';


export class DiscoveryResult {
  totalHosts: number;
  totalServices: number;
  elapsedTime: string;

  hTimer: any;

  constructor() {
    this.totalHosts = 0;
    this.totalServices = 0;
    this.elapsedTime = '00:00:00';
  }

  start() {
    const __this = this;
    const startTime = new Date().getTime();
    this.hTimer = setInterval(function () {
      // Get todays date and time
      const now = new Date().getTime();

      // Find the distance between now and the count down date
      const distance = now - startTime;

      // Time calculations for days, hours, minutes and seconds
      const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
      const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
      const seconds = Math.floor((distance % (1000 * 60)) / 1000);

      __this.setElapsedTime(hours, minutes, seconds);
    }, 1000);
  }

  setElapsedTime(hour: number, minute: number, second: number) {
    this.elapsedTime = String(hour).padStart(2, '0') + ':' + String(minute).padStart(2, '0') + ':' + String(second).padStart(2, '0');
  }

  stop(hours: number, minutes: number, seconds: number) {
    clearInterval(this.hTimer);
    this.setElapsedTime(hours, minutes, seconds);
  }

  increaseHost() {
    this.totalHosts++;
  }

  increaseService() {
    this.totalServices++;
  }
}

@Component({
  selector: 'app-discovery-map',
  templateUrl: './discovery-map.component.html',
  styleUrls: ['./discovery-map.component.scss']
})
export class DiscoveryMapComponent implements OnInit {
  @Input() zone: Zone;

  @Input() nodes: Node[];

  @Input() links: Link[];


  @ViewChild('discoveryTarget') set discoveryTarget(content: ElementRef) {
    this.discoveryTargetRef = content;
  }

  private discoveryTargetRef: ElementRef;
  public simulation: d3.Simulation<Node, Link> | undefined;
  private zoomBehavior: d3.ZoomBehavior<Element, {}>;
  private discoveryContainerWidth: number;
  private discoveryContainerHeight: number;
  private readonly maxScale: number;
  private readonly minScale: number;

  constructor() { }

  ngOnInit(): void {

  }
}
